SavedDownload class

The result of copyFileIntoDownloadFolder.

Wraps both the saved file's on-disk path and (on Android 10+) the MediaStore content:// URI that should be used for any further I/O, sharing, or system intents.

Constructors

SavedDownload({required File file, Uri? contentUri})
const

Properties

contentUri Uri?
The MediaStore content:// URI for the saved file on Android 10+.
final
file File
The file location on disk.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited